<?php
/**
 * @see Alinks_Cacher_Interface
 */
require_once('Alinks/Cacher/Interface.php');

/**
 * Used to disable caching
 *
 * Copyright (C) 2008  Sean Hickey
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @author Jonathan Tappan <jtappan@bugfox.net>
 * @version $Id: Dummy.php 387 2012-10-31 05:35:19Z jt $
 * @package Alinks_Cacher
 */
class Alinks_Cacher_Dummy implements Alinks_Cacher_Interface
{
	/**
	 * Code placed at the top of all cache files
	 */
	const TOP = "<?php die(); ?>\r\n";
	
	/**
	 * Index array key for expiration
	 */
	const EXPIRATION = 'expiration';
	
	/**
	 * Index array key for when the file was created
	 */
	const CREATED = 'created';
	
	/**
	 * The cache options
	 *
	 * @var array
	 */
	protected $_options = array();
	
	/**
	 * Constructor
	 *
	 * @param array $options The cache options
	 */
	public function __construct(array $options)
	{
		$this->setOptions($options);
	}
	
	/**
	 * Sets the caching options
	 *
	 * @param array $options The options
	 * @return Alinks_Cacher_Dummy
	 * @throws Alinks_Cacher_Exception
	 */
	public function setOptions(array $options)
	{
		$this->_options = $options;
		return $this;
	}
	
	/**
	 * Returns the caching options
	 *
	 * @return array
	 */
	public function getOptions()
	{
		return $this->_options;
	}
	
	/**
	 * Returns if cached content exists for the given key
	 *
	 * @param string $key The cache key
	 * @param string $namespace The cache namespace
	 * @return bool
	 */
	public function exists($key, $namespace)
	{
		return false;
	}
	
	/**
	 * Sets content to be cached
	 *
	 * @param string $key The cache key
	 * @param string $namespace The cache namespace
	 * @param mixed $value The cache value
	 * @param int $expires Number of seconds to keep the value cached
	 * @return Alinks_Cacher_Dummy
	 */
	public function set($key, $namespace, $value, $expires = 0)
	{
	return $this;
	}
	
	/**
	 * Returns cached content
	 *
	 * Throws a Alinks_Cacher_Exception if no cache exists for the
	 * given key and namspace. Use exists() first to be sure the cached
	 * content exists.
	 *
	 * @param string $key The cache key
	 * @param string $namespace The cache namespace
	 * @return mixed
	 */
	public function get($key, $namespace)
	{
		throw new Alinks_Cacher_Exception("No cache exists for $key in namespace $namespace");
	}
	
	/**
	 * Deletes any cached content for the given key and namespace
	 *
	 * Returns true if the cache was deleted, false if not. False doesn't
	 * mean an error. It could just mean there was no cache to delete.
	 *
	 * @param string $key The cache key
	 * @param string $namespace The cache namepsace
	 * @return bool
	 */
	public function delete($key, $namespace)
	{
		return true;
	}
	
	/**
	 * Flushes the cache for a specific namespace
	 *
	 * This method always returns true.
	 *
	 * @param string $namespace The cache namespace
	 * @return bool
	 */
	public function flush($namespace = null)
	{
		return true;
	}
	
	/**
	 * Flushes out the entire cache
	 *
	 * This method always returns true.
	 *
	 * @return bool
	 */
	protected function _flushAll()
	{
		return true;
	}
}